Personally Identifiable Information (PII) is, according to NIST Special Publication 800-122, a collective term for any
information that can be used to distinguish or trace an individual's identity, such as name, social security number,
date and place of birth, mother's maiden name, or biometric records; and any other information that is linked or
linkable to an individual, such as medical, educational, financial, and employment information.